import * as cdk from 'aws-cdk-lib';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import * as ecs from 'aws-cdk-lib/aws-ecs';
import { Construct } from 'constructs';
/**
 * Props for `TmEcsDeploymentHook`.
 */
export interface TmEcsDeploymentHookProps extends cdk.StackProps {
    /**
     * The ECS task definition to run.
     */
    taskDefinition: ecs.FargateTaskDefinition;
    /**
     * The ECS cluster where the task will be run.
     */
    cluster: ecs.ICluster;
    /**
     * The subnets where the task will be launched.
     */
    subnets: ec2.ISubnet[];
    /**
     * The security groups to associate with the task.
     */
    securityGroups: ec2.ISecurityGroup[];
    /**
     * The name of the container in the task definition.
     */
    containerName: string;
    /**
     * The command to run in the container.
     * This should be an array of strings, where the first element is the command and the subsequent elements are its arguments.
     */
    command: string[];
}
export declare class TmEcsDeploymentHook extends Construct {
    constructor(scope: Construct, id: string, props: TmEcsDeploymentHookProps);
}
